@@ -7,6 +7,8 @@
 pub mod algorithms;
 pub mod beam;
 pub mod candidate;
+pub mod connected_components_transformer;
+pub mod strongly_connected_components_transformer;
 pub mod core_transformer;
 pub mod error;
 pub mod graph_base;
